==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SubsetFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubsetFluentImpl<A extends SubsetFluent<A>> extends BaseFluent<A> implements SubsetFluent<A>{
  public SubsetFluentImpl() {
  }
  public SubsetFluentImpl(Subset instance) {
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withTrafficPolicy(instance.getTrafficPolicy()); 
  }
  private Map<String,String> labels;
  private String name;
  private TrafficPolicyBuilder trafficPolicy;
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public Boolean hasLabels() {
    return this.labels != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTrafficPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public TrafficPolicy getTrafficPolicy() {
    return this.trafficPolicy!=null ?this.trafficPolicy.build():null;
  }
  public TrafficPolicy buildTrafficPolicy() {
    return this.trafficPolicy!=null ?this.trafficPolicy.build():null;
  }
  public A withTrafficPolicy(TrafficPolicy trafficPolicy) {
    _visitables.get("trafficPolicy").remove(this.trafficPolicy);
    if (trafficPolicy!=null){ this.trafficPolicy= new TrafficPolicyBuilder(trafficPolicy); _visitables.get("trafficPolicy").add(this.trafficPolicy);} else { this.trafficPolicy = null; _visitables.get("trafficPolicy").remove(this.trafficPolicy); } return (A) this;
  }
  public Boolean hasTrafficPolicy() {
    return this.trafficPolicy != null;
  }
  public SubsetFluent.TrafficPolicyNested<A> withNewTrafficPolicy() {
    return new SubsetFluentImpl.TrafficPolicyNestedImpl();
  }
  public SubsetFluent.TrafficPolicyNested<A> withNewTrafficPolicyLike(TrafficPolicy item) {
    return new SubsetFluentImpl.TrafficPolicyNestedImpl(item);
  }
  public SubsetFluent.TrafficPolicyNested<A> editTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy());
  }
  public SubsetFluent.TrafficPolicyNested<A> editOrNewTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): new TrafficPolicyBuilder().build());
  }
  public SubsetFluent.TrafficPolicyNested<A> editOrNewTrafficPolicyLike(TrafficPolicy item) {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubsetFluentImpl that = (SubsetFluentImpl) o;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (trafficPolicy != null ? !trafficPolicy.equals(that.trafficPolicy) :that.trafficPolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  name,  trafficPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (trafficPolicy != null) { sb.append("trafficPolicy:"); sb.append(trafficPolicy); }
    sb.append("}");
    return sb.toString();
  }
  class TrafficPolicyNestedImpl<N> extends TrafficPolicyFluentImpl<SubsetFluent.TrafficPolicyNested<N>> implements SubsetFluent.TrafficPolicyNested<N>,Nested<N>{
    TrafficPolicyNestedImpl(TrafficPolicy item) {
      this.builder = new TrafficPolicyBuilder(this, item);
    }
    TrafficPolicyNestedImpl() {
      this.builder = new TrafficPolicyBuilder(this);
    }
    TrafficPolicyBuilder builder;
    public N and() {
      return (N) SubsetFluentImpl.this.withTrafficPolicy(builder.build());
    }
    public N endTrafficPolicy() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SubsetFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubsetFluentImpl<A extends SubsetFluent<A>> extends BaseFluent<A> implements SubsetFluent<A>{
  public SubsetFluentImpl() {
  }
  public SubsetFluentImpl(Subset instance) {
    if (instance != null) {
      this.withLabels(instance.getLabels());
      this.withName(instance.getName());
      this.withTrafficPolicy(instance.getTrafficPolicy());
    }
  }
  private Map<String,String> labels;
  private String name;
  private TrafficPolicyBuilder trafficPolicy;
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public Boolean hasLabels() {
    return this.labels != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTrafficPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public TrafficPolicy getTrafficPolicy() {
    return this.trafficPolicy!=null ?this.trafficPolicy.build():null;
  }
  public TrafficPolicy buildTrafficPolicy() {
    return this.trafficPolicy!=null ?this.trafficPolicy.build():null;
  }
  public A withTrafficPolicy(TrafficPolicy trafficPolicy) {
    _visitables.get("trafficPolicy").remove(this.trafficPolicy);
    if (trafficPolicy!=null){ this.trafficPolicy= new TrafficPolicyBuilder(trafficPolicy); _visitables.get("trafficPolicy").add(this.trafficPolicy);} else { this.trafficPolicy = null; _visitables.get("trafficPolicy").remove(this.trafficPolicy); } return (A) this;
  }
  public Boolean hasTrafficPolicy() {
    return this.trafficPolicy != null;
  }
  public SubsetFluentImpl.TrafficPolicyNested<A> withNewTrafficPolicy() {
    return new SubsetFluentImpl.TrafficPolicyNestedImpl();
  }
  public SubsetFluentImpl.TrafficPolicyNested<A> withNewTrafficPolicyLike(TrafficPolicy item) {
    return new SubsetFluentImpl.TrafficPolicyNestedImpl(item);
  }
  public SubsetFluentImpl.TrafficPolicyNested<A> editTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy());
  }
  public SubsetFluentImpl.TrafficPolicyNested<A> editOrNewTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): new TrafficPolicyBuilder().build());
  }
  public SubsetFluentImpl.TrafficPolicyNested<A> editOrNewTrafficPolicyLike(TrafficPolicy item) {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubsetFluentImpl that = (SubsetFluentImpl) o;
    if (!java.util.Objects.equals(labels, that.labels)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(trafficPolicy, that.trafficPolicy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  name,  trafficPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (trafficPolicy != null) { sb.append("trafficPolicy:"); sb.append(trafficPolicy); }
    sb.append("}");
    return sb.toString();
  }
  class TrafficPolicyNestedImpl<N> extends TrafficPolicyFluentImpl<SubsetFluentImpl.TrafficPolicyNested<N>> implements SubsetFluentImpl.TrafficPolicyNested<N>,Nested<N>{
    TrafficPolicyNestedImpl(TrafficPolicy item) {
      this.builder = new TrafficPolicyBuilder(this, item);
    }
    TrafficPolicyNestedImpl() {
      this.builder = new TrafficPolicyBuilder(this);
    }
    TrafficPolicyBuilder builder;
    public N and() {
      return (N) SubsetFluentImpl.this.withTrafficPolicy(builder.build());
    }
    public N endTrafficPolicy() {
      return and();
    }
    
  }
  
}
